<?php
/**
 * @file
 * Contains \Drupal\generator_ui\Form\GeneratorBlock .
 *
 */
namespace Drupal\generator_ui\Form;


use Drupal\Core\Form\FormStateInterface;
use Drupal\generator_ui\Controller\GeneratorController;

class GeneratorBlock extends Generator {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'generator_block';
  }

  /**
   * Form constructor.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['into'] = array(
      '#markup' => t('<h2>' . 'Please fill the blanks to create your Block in D8' . '</h2>'),
      "#weight" => -3

    );
    $form['twig_file'] = array(
      "#type" => 'hidden',
      "#value" => array('class_block'=>'block.php.twig'),
    );

    $form['class_block'] = array(
      '#type' => 'textfield',
      '#title' => t('Name of the block class'),
      '#default_value' => 'ExampleBlock',
      '#description' => t('Path of Block class depends on it and will be placed in modules/src/Plugin/Block/xxx'),
      '#required' => TRUE,
    );
    $form['id_block'] = array(
      '#type' => 'textfield',
      '#title' => t('Id of the block'),
      '#description' => t('Internal ID of the block for code use.'),
      '#default_value' => 'id_block',
      '#required' => TRUE,
    );
    $form['admin_label'] = array(
      '#type' => 'textfield',
      '#title' => t('Label of the block'),
      '#default_value' => t('Hello !'),
      '#description' => t('Label that appears in the list of blocks in the block administration page.'),
      '#required' => TRUE,
    );
    $form['category'] = array(
      '#type' => 'textfield',
      '#title' => t('Category of the block'),
      '#default_value' => t('My new category'),
      '#description' => t('Grouping blocks together on the block admin page. If not set, name of the module is used.'),
      '#required' => FALSE,
    );
    $form['text'] = array(
      '#type' => 'textfield',
      '#title' => t('Text to display'),
      '#default_value' => t('Hello world !'),
      '#description' => t('Label that appears in the list of blocks in the block administration page.'),
      '#required' => TRUE,
    );
    $form = parent::buildForm($form, $form_state);
    return $form;
  }
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    return parent::validateForm($form, $form_state);
  }

  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    return parent::submitForm($form, $form_state);
  }
}