<?php

/**
 * @file
 * Contains \Drupal\generator_ui\Form\GeneratorInfo .
 *
 */

namespace Drupal\generator_ui\Form;

//Use the necessary libraries
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Render\Element\Url;
use Drupal\generator_ui\Controller\GeneratorController;


class GeneratorEntity  extends Generator {

  /**
   * Returns a unique string identifying the form.
   *
   * @return string
   *   The unique string identifying the form.
   */
  public function getFormId() {
    return 'manipulation_entity';

  }

  /**
   * Form constructor.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return array
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $form['into'] = array(
      '#markup' => t('<h2>' . 'Please fill the blanks to manipulate entity in D8' . '</h2>'),
      "#weight" => -2
    );
    $form['twig_file'] = array(
      "#type" => 'hidden',
      "#value" => array('entity.module.yml.twig'),
    );
    $form['create_entity'] = array(
      '#type' => 'checkbox',
      '#title' => t('Create entity'),
      '#default_value' => '1',
      '#description' => t('Check if you want to generate how to create entity in drupal 8.'),
    );
    $form['create_entity_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Create entity'),
      '#collapsible' => TRUE,
      '#states' => array(
        'visible' => array(
          ':input[name="create_entity"]' => array('checked' => TRUE),
        ),
      ),
    );

    $form['create_entity_fieldset']['entity_type_create'] = array(
      '#type' => 'textfield',
      '#title' => 'Entity type',
      '#default_value' => 'node',
      '#description' => t('The Entity type : node,user'),
      '#required' => true,
    );
    $form['create_entity_fieldset']['contents'] = array(
      '#type' => 'textfield',
      '#title' => 'Content',
      '#default_value' => '',
      '#description' => t('The content : page,article, <string>if we don\'t have a content in entity type like user,leave it blank</string>'),
    );
    $form['modify_entity'] = array(
      '#type' => 'checkbox',
      '#title' => t('Modification of a field of the entity created'),
      '#default_value' => '0',
      '#description' => t('Check if you want to generate how to modify entity in drupal 8.'),
    );
    $form['modify_entity_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Create entity'),
      '#collapsible' => TRUE,
      '#states' => array(
        'visible' => array(
          ':input[name="modify_entity"]' => array('checked' => TRUE),
        ),
      ),
    );
    $form['modify_entity_fieldset']['entity_type_modify'] = array(
      '#type' => 'textfield',
      '#title' => 'Entity type',
      '#default_value' => 'node',
      '#description' => t('The Entity type : node,user'),
      '#required' => true,
    );
    $form['delete_entity'] = array(
      '#type' => 'checkbox',
      '#title' => t('Delete entity'),
      '#default_value' => '0',
      '#description' => t('Check if you want to generate how to delete entity in drupal 8.'),
    );
    $form['delete_entity_fieldset'] = array(
      '#type' => 'fieldset',
      '#title' => $this->t('Delete entity'),
      '#collapsible' => TRUE,
      '#states' => array(
        'visible' => array(
          ':input[name="delete_entity"]' => array('checked' => TRUE),
        ),
      ),
    );
    $form['delete_entity_fieldset']['entity_type_delete'] = array(
      '#type' => 'textfield',
      '#title' => 'Entity type',
      '#default_value' => 'node',
      '#description' => t('The Entity type : node,user'),
      '#required' => true,
    );
    $form = parent::buildForm($form, $form_state);
    unset($form['module_name']);
    unset($form['btn_create']);
    unset($form['btn_download']);

    return $form;

  }
  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    return parent::validateForm($form, $form_state);
  }
  /**
   * Form submission handler.
   *
   * @param array $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   */
  public
  function submitForm(array &$form, FormStateInterface $form_state) {
    return parent::submitForm($form, $form_state);

  }
}